#
# spec file for package discover6
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 5.245.0
%define qt6_version 6.6.0
%define rname discover
%bcond_without released
# Version in Leap 15 < 15.6 is too old
%global have_fwupd (0%{?suse_version} > 1500 || 0%{?sle_version} >= 150600)

Name:           discover6
Version:        6.0.5
Release:        1.1
Summary:        Software store for the KDE Plasma desktop
License:        GPL-2.0-only AND GPL-3.0-only AND GPL-3.0-or-later
URL:            https://apps.kde.org/discover/
Source:         https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
# PATCH-FIX-OPENSUSE
Patch0:         0001-Warning-for-FlatHub.patch
BuildRequires:  flatpak-devel
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(AppStreamQt) >= 1.0.0
BuildRequires:  cmake(KF6Archive) >= %{kf6_version}
BuildRequires:  cmake(KF6Attica) >= %{kf6_version}
BuildRequires:  cmake(KF6Auth) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6IdleTime) >= %{kf6_version}
BuildRequires:  cmake(KF6KCMUtils) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Kirigami) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons)
BuildRequires:  cmake(KF6NewStuff) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6Purpose) >= %{kf6_version}
BuildRequires:  cmake(KF6StatusNotifierItem) >= %{kf6_version}
BuildRequires:  cmake(KF6UserFeedback) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
# Only available on archs providing QtWebEngine
%ifarch x86_64 aarch64 riscv64
BuildRequires:  cmake(Qt6WebView) >= %{qt6_version}
%endif
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}
BuildRequires:  cmake(packagekitqt6) >= 1.0.1
%if %{have_fwupd}
BuildRequires:  pkgconfig(fwupd) >= 1.9.4
%endif
%if 0%{?suse_version} > 1500
BuildRequires:  pkgconfig(libmarkdown) >= 3.0
%endif
Requires:       kf6-kdeclarative-imports >= %{kf6_version}
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kf6-kuserfeedback-imports >= %{kf6_version}
Requires:       kirigami-addons6
Requires:       qt6-declarative-imports >= %{qt6_version}
Recommends:     discover-backend-flatpak
Recommends:     discover6-backend-fwupd
Recommends:     discover6-backend-packagekit
Recommends:     discover6-notifier
Provides:       discover = %{version}
Obsoletes:      discover < %{version}
Obsoletes:      discover-lang < %{version}

%description
Discover is a graphical software manager for the KDE Plasma desktop. It helps users to find software they might want easily and quickly.

By allowing to navigate a software library by search, categories, top lists along with detailed application information including screenshots and reviews, users can more quickly find applications that suit their needs.

%package backend-packagekit
Summary:        PackageKit Backend for Discover
Requires:       PackageKit
Requires:       appstream-provider
Requires:       discover6 = %{version}
# Technically libdiscover and not the backend implements AppStream support, but
# it's useless without system package management
%requires_eq    AppStream
Provides:       discover-backend-packagekit = %{version}
Obsoletes:      discover-backend-packagekit < %{version}

%description backend-packagekit
A plugin for Discover to support management of system packages and repositories
using PackageKit.

%package backend-flatpak
Summary:        Flatpak Backend for Discover
Requires:       discover6 = %{version}
Requires:       flatpak
Provides:       discover-backend-flatpak = %{version}
Obsoletes:      discover-backend-flatpak < %{version}

%description backend-flatpak
A plugin for Discover to support installation and management of Flatpak
applications and repositories.

%if %{have_fwupd}
%package backend-fwupd
Summary:        fwupd Backend for Discover
Requires:       discover6 = %{version}
Provides:       discover-backend-fwupd = %{version}
Obsoletes:      discover-backend-fwupd < %{version}

%description backend-fwupd
A plugin for Discover to support updates of system firmware using fwupd.
%endif

%package notifier
Summary:        Update notifier for KDE Software Manager
Requires:       discover6 = %{version}
Obsoletes:      discover-plasmoid < %{version}
Obsoletes:      plasma5-pk-updates < 0.3.3
Obsoletes:      plasma5-pk-updates-lang < 0.3.3
Provides:       discover-notifier = %{version}
Obsoletes:      discover-notifier < %{version}

%description notifier
This is a notifier for Discover to inform the user that updates are available and allows the
user to install them using Discover.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%suse_update_desktop_file -r org.kde.discover Qt KDE System PackageManager

# Even without the snap backend, this is installed...
rm %{buildroot}%{_kf6_applicationsdir}/org.kde.discover.snap.desktop

%find_lang libdiscover %{name}.lang
%find_lang plasma-discover %{name}.lang

%find_lang plasma-discover-notifier notifier.lang
%find_lang kcm_updates notifier.lang

%files
%license LICENSES/*
%dir %{_kf6_plugindir}/discover/
%{_kf6_applicationsdir}/org.kde.discover.desktop
%{_kf6_applicationsdir}/org.kde.discover.urlhandler.desktop
%{_kf6_appstreamdir}/org.kde.discover.appdata.xml
%{_kf6_bindir}/plasma-discover
%{_kf6_bindir}/plasma-discover-update
%{_kf6_debugdir}/discover.categories
%{_kf6_iconsdir}/hicolor/*/apps/plasmadiscover.*
%{_kf6_kxmlguidir}/plasmadiscover/
%{_kf6_libdir}/plasma-discover/
%{_kf6_notificationsdir}/discoverabstractnotifier.notifyrc
%{_kf6_plugindir}/discover/kns-backend.so
%dir %{_kf6_sharedir}/libdiscover
%dir %{_kf6_sharedir}/libdiscover/categories

%files lang -f %{name}.lang

%files backend-packagekit
%license LICENSES/*
%{_kf6_plugindir}/discover/packagekit-backend.so
%{_kf6_sharedir}/libdiscover/categories/packagekit-backend-categories.xml
%{_kf6_appstreamdir}/org.kde.discover.packagekit.appdata.xml

%files backend-flatpak
%license LICENSES/*
%{_kf6_plugindir}/discover/flatpak-backend.so
%{_kf6_sharedir}/libdiscover/categories/flatpak-backend-categories.xml
%{_kf6_appstreamdir}/org.kde.discover.flatpak.appdata.xml
%{_kf6_applicationsdir}/org.kde.discover-flatpak.desktop
%{_kf6_iconsdir}/hicolor/scalable/apps/flatpak-discover.svg

%if %{have_fwupd}
%files backend-fwupd
%license LICENSES/*
%{_kf6_plugindir}/discover/fwupd-backend.so
%endif

%files notifier -f notifier.lang
%license LICENSES/*
%{_kf6_applicationsdir}/kcm_updates.desktop
%dir %{_kf6_plugindir}/discover-notifier
%{_kf6_plugindir}/discover-notifier/DiscoverPackageKitNotifier.so
%{_kf6_plugindir}/discover-notifier/FlatpakNotifier.so
%{_kf6_configdir}/autostart/org.kde.discover.notifier.desktop
%{_kf6_applicationsdir}/org.kde.discover.notifier.desktop
%{_kf6_plugindir}/plasma/kcms/systemsettings/kcm_updates.so
%{_libexecdir}/DiscoverNotifier

%changelog
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4:
  * remove dup version
  * update version for new release
  * flatpak: don't trip over nullptr remotes when installing a flatpakref
  * flatpak: Check specifically installed files when looking up installed ones (kde#482518)
  * notifier: Assume online if no QNetworkInformation instance available
  * kns: drop provider part of the url (kde#486330)
  * packagekit: return empty license array when unknown (kde#486037)
  * FwupdBackend: Set user agent from client (kde#486726)
  * flatpak: Do not report regressions on transaction progress
  * flatpak&pk: Do not use QIcon to check if an appstream icon exists
  * UpdatesPage: Fix invisible delegates taking up space and causing a ghost section header (kde#478253)
  * UpdatesPage: Port from custom QSortFilterProxyModel subclass to KItemModels
- Drop patches, now upstream:
  * 0001-notifier-Assume-online-if-no-QNetworkInformation-ins.patch
* Thu May 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix the notifier if NetworkManager is not used (boo#1224321):
  * 0001-notifier-Assume-online-if-no-QNetworkInformation-ins.patch
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4
- Changes since 6.0.3:
  * update version for new release
  * packagekit: make sure to load all packages when necessary
  * flatpak: don't crash on elsewhere consumed streams
  * flatpak: change deferredResultStream to template
  * revert premature appstream update
  * update version for new release
  * GridApplicationDelegate: Wrap labels, don't let them overflow
  * packagekit: only resolve dependencies for resources in None state (kde#464467)
  * flatpak, packagekit: fix threaded deadlock in dlopen/gmodule (kde#481993)
  * update version for new release
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * revert duplicated appstream edit
  * update version for new release
  * kns: Make sure we only launch requests once
  * kns: fix entry deduplication
  * packagekitbackend: de-thread the appstream loading hotfix
  * Fix build with c++17
  * flatpak: Rescue local files that might exist before creating a new file
* Mon Mar 18 2024 Christophe Marin <christophe@krop.fr>
- Update recommended packages
* Mon Mar 18 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Also obsolete plasma5-pk-updates-lang
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * update version for new release
  * fix appstream warnign url-homepage-missing
  * kns: Make sure we don't emit twice the same resource (kde#482095)
  * update version for new release
* Thu Mar  7 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Enable fwupd integration on Leap 15.6+
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
* Mon Mar  4 2024 Christophe Marin <christophe@krop.fr>
- Add Provides/Obsoletes to replace Plasma 5
* Wed Feb 28 2024 Christophe Marin <christophe@krop.fr>
- Update QML dependencies
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * update version for new release
  * flatpak: Fix loading a flatpakref when we already have the repository added
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- Changes since 5.92.0:
  * Adapt to move of KNSCore::ErrorCode enum nested namespace
  * Flatpak: Fix up prompt to delete uninstalled app's data (kde#478704)
  * Improve time to a ready startup page
  * Do not use the currentSubMenu to reset the view
  * discover: Make status view the drawer's footer
  * flatpak: Finalize refresh even when appstream pool was already loaded
  * Fix missing Addons button/view (kde#477772)
  * Home page: span and wrap title labels (kde#476898)
  * Fix 'Still looking' text centering (kde#479737)
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Tue Dec 19 2023 Christophe Marin <christophe@krop.fr>
- Init discover6
